@@ -1,21 +1,8 @@
-/* This file is part of the KDE libraries
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2007-2009 David Faure <faure@kde.org>
 
-    Copyright 2007-2009 David Faure <faure@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kxmlgui_unittest.h"
@@ -109,7 +96,7 @@ static void clickApply(KEditToolBar *dialog)
 
 void KXmlGui_UnitTest::initTestCase()
 {
-    QStandardPaths::enableTestMode(true);
+    QStandardPaths::setTestModeEnabled(true);
     // Leftover configuration breaks testAutoSaveSettings
     const QString configFile = QStandardPaths::locate(QStandardPaths::GenericConfigLocation, KSharedConfig::openConfig()->name());
     if (!configFile.isEmpty()) {
@@ -148,7 +135,7 @@ void KXmlGui_UnitTest::testFindVersionNumber()
 {
     QFETCH(QString, xml);
     QFETCH(QString, version);
-    QCOMPARE(KXmlGuiVersionHandler::findVersionNumber(xml), version);
+    QCOMPARE(KXMLGUIClient::findVersionNumber(xml), version);
 }
 
 void KXmlGui_UnitTest::testVersionHandlerSameVersion()
@@ -174,12 +161,12 @@ void KXmlGui_UnitTest::testVersionHandlerSameVersion()
     KXmlGuiVersionHandler versionHandler(files);
     QCOMPARE(versionHandler.finalFile(), firstFile);
     QString finalDoc = versionHandler.finalDocument();
-    QVERIFY(finalDoc.startsWith(QStringLiteral("<?xml")));
+    QVERIFY(finalDoc.startsWith(QLatin1String("<?xml")));
     // Check that the shortcuts defined by the user were kept
-    QVERIFY(finalDoc.contains(QStringLiteral("<ActionProperties>")));
-    QVERIFY(finalDoc.contains(QStringLiteral("sidebartng")));
+    QVERIFY(finalDoc.contains(QLatin1String("<ActionProperties>")));
+    QVERIFY(finalDoc.contains(QLatin1String("sidebartng")));
     // Check that the toolbars modified by the user were kept
-    QVERIFY(finalDoc.contains(QStringLiteral("<Action name=\"home\"")));
+    QVERIFY(finalDoc.contains(QLatin1String("<Action name=\"home\"")));
 
     QVERIFY(userFile.open());
     const QString userFileContents = QString::fromUtf8(userFile.readAll());
@@ -224,8 +211,8 @@ void KXmlGui_UnitTest::testVersionHandlerNewVersionNothingKept()
     KXmlGuiVersionHandler versionHandler(files);
     QCOMPARE(fileToVersionMap.value(versionHandler.finalFile()), 5);
     QString finalDoc = versionHandler.finalDocument();
-    QVERIFY(finalDoc.startsWith(QStringLiteral("<?xml")));
-    QVERIFY(finalDoc.contains(QStringLiteral("version=\"5\"")));
+    QVERIFY(finalDoc.startsWith(QLatin1String("<?xml")));
+    QVERIFY(finalDoc.contains(QLatin1String("version=\"5\"")));
 
     QVERIFY(fileV5.open());
     const QString fileV5Contents = QString::fromUtf8(fileV5.readAll());
@@ -272,22 +259,22 @@ void KXmlGui_UnitTest::testVersionHandlerNewVersionUserChanges()
     QCOMPARE(fileToVersionMap.value(versionHandler.finalFile()), 2);
     const QString finalDoc = versionHandler.finalDocument();
     //qDebug() << finalDoc;
-    QVERIFY(finalDoc.startsWith(QStringLiteral("<?xml")));
-    QVERIFY(finalDoc.contains(QStringLiteral("version=\"5\"")));
+    QVERIFY(finalDoc.startsWith(QLatin1String("<?xml")));
+    QVERIFY(finalDoc.contains(QLatin1String("version=\"5\"")));
     // Check that the shortcuts defined by the user were kept
-    QVERIFY(finalDoc.contains(QStringLiteral("<ActionProperties>")));
-    QVERIFY(finalDoc.contains(QStringLiteral("sidebartng")));
+    QVERIFY(finalDoc.contains(QLatin1String("<ActionProperties>")));
+    QVERIFY(finalDoc.contains(QLatin1String("sidebartng")));
     // Check that the menus modified by the app are still there
-    QVERIFY(finalDoc.contains(QStringLiteral("<Action name=\"file_open\"")));
+    QVERIFY(finalDoc.contains(QLatin1String("<Action name=\"file_open\"")));
     // Check that the toolbars modified by the user were kept
-    QVERIFY(finalDoc.contains(QStringLiteral("<Action name=\"home\"")));
+    QVERIFY(finalDoc.contains(QLatin1String("<Action name=\"home\"")));
 }
 
 static QStringList collectMenuNames(KXMLGUIFactory &factory)
 {
-    QList<QWidget *> containers = factory.containers(QStringLiteral("Menu"));
+    const QList<QWidget *> containers = factory.containers(QStringLiteral("Menu"));
     QStringList containerNames;
-    Q_FOREACH (QWidget *w, containers) {
+    for (QWidget *w : containers) {
         containerNames << w->objectName();
     }
     return containerNames;
@@ -295,7 +282,7 @@ static QStringList collectMenuNames(KXMLGUIFactory &factory)
 
 void debugActions(const QList<QAction *> &actions)
 {
-    Q_FOREACH (QAction *action, actions) {
+    for (QAction *action : actions) {
         qDebug() << (action->isSeparator() ? QString::fromLatin1("separator") : action->objectName());
     }
 }
@@ -892,6 +879,7 @@ void KXmlGui_UnitTest::testTopLevelSeparator()
                  << QStringLiteral("before_separator")
                  << QStringLiteral("separator")
                  << QStringLiteral("after_separator")
+                 << QStringLiteral("settings")
                  << QStringLiteral("separator")
                  << QStringLiteral("help"));
 }
@@ -913,6 +901,7 @@ void KXmlGui_UnitTest::testMenuNames()
 
     checkActions(mainWindow.menuBar()->actions(), QStringList()
                  << QStringLiteral("filemenu")
+                 << QStringLiteral("settings")
                  << QStringLiteral("separator")
                  << QStringLiteral("help"));
 }
@@ -924,8 +913,7 @@ void KXmlGui_UnitTest::testMenusNoXmlFile()
     TestXmlGuiWindow mainWindow(QByteArray(), "nolocalfile_either.rc");
     mainWindow.createGUIBad();
 
-    checkActions(mainWindow.menuBar()->actions(), QStringList()
-                 << QStringLiteral("help"));
+    checkActions(mainWindow.menuBar()->actions(), QStringList{QStringLiteral("settings"), QStringLiteral("separator"), QStringLiteral("help")});
 }
 
 void KXmlGui_UnitTest::testXMLFileReplacement()
@@ -955,23 +943,23 @@ void KXmlGui_UnitTest::testXMLFileReplacement()
     client.setXMLFilePublic(filenameOrig);
     QString xml = client.domDocument().toString();
     //qDebug() << xml;
-    QVERIFY(xml.contains(QStringLiteral("<Action name=\"print\"")));
-    QVERIFY(!xml.contains(QStringLiteral("<Action name=\"home\"")));
-    QVERIFY(!xml.contains(QStringLiteral("<ActionProperties>")));
+    QVERIFY(xml.contains(QLatin1String("<Action name=\"print\"")));
+    QVERIFY(!xml.contains(QLatin1String("<Action name=\"home\"")));
+    QVERIFY(!xml.contains(QLatin1String("<ActionProperties>")));
 
     // now test the replacement (+ local file)
     client.replaceXMLFile(filenameReplace, filenameLocal);
     xml = client.domDocument().toString();
-    QVERIFY(!xml.contains(QStringLiteral("<Action name=\"print\"")));
-    QVERIFY(xml.contains(QStringLiteral("<Action name=\"home\"")));
-    QVERIFY(xml.contains(QStringLiteral("<ActionProperties>")));
+    QVERIFY(!xml.contains(QLatin1String("<Action name=\"print\"")));
+    QVERIFY(xml.contains(QLatin1String("<Action name=\"home\"")));
+    QVERIFY(xml.contains(QLatin1String("<ActionProperties>")));
 
     // re-check after a reload
     client.reloadXML();
     QString reloadedXml = client.domDocument().toString();
-    QVERIFY(!reloadedXml.contains(QStringLiteral("<Action name=\"print\"")));
-    QVERIFY(reloadedXml.contains(QStringLiteral("<Action name=\"home\"")));
-    QVERIFY(reloadedXml.contains(QStringLiteral("<ActionProperties>")));
+    QVERIFY(!reloadedXml.contains(QLatin1String("<Action name=\"print\"")));
+    QVERIFY(reloadedXml.contains(QLatin1String("<Action name=\"home\"")));
+    QVERIFY(reloadedXml.contains(QLatin1String("<ActionProperties>")));
 
     // Check what happens when the local file doesn't exist
     TestGuiClient client2;
@@ -979,9 +967,9 @@ void KXmlGui_UnitTest::testXMLFileReplacement()
     client2.replaceXMLFile(filenameReplace, filenameLocal);
     xml = client2.domDocument().toString();
     //qDebug() << xml;
-    QVERIFY(!xml.contains(QStringLiteral("<Action name=\"print\"")));
-    QVERIFY(xml.contains(QStringLiteral("<Action name=\"home\""))); // modified toolbars
-    QVERIFY(!xml.contains(QStringLiteral("<ActionProperties>"))); // but no local xml file
+    QVERIFY(!xml.contains(QLatin1String("<Action name=\"print\"")));
+    QVERIFY(xml.contains(QLatin1String("<Action name=\"home\""))); // modified toolbars
+    QVERIFY(!xml.contains(QLatin1String("<ActionProperties>"))); // but no local xml file
 }
 
 void KXmlGui_UnitTest::testClientDestruction()   // #170806
@@ -1013,16 +1001,15 @@ void KXmlGui_UnitTest::testClientDestruction()   // #170806
     mainWindow.insertChildClient(client);
     mainWindow.createGUI();
 
-    checkActions(mainWindow.menuBar()->actions(), QStringList()
-                 << QStringLiteral("file") << QStringLiteral("separator") << QStringLiteral("help"));
+    const QStringList menus = { QStringLiteral("file"), QStringLiteral("settings"), QStringLiteral("separator"), QStringLiteral("help") };
+    checkActions(mainWindow.menuBar()->actions(), menus);
 
     QVERIFY(mainWindow.factory()->clients().contains(client));
     delete client;
     QVERIFY(!mainWindow.factory()->clients().contains(client));
 
     // No change, because deletion is fast, it doesn't do manual unplugging.
-    checkActions(mainWindow.menuBar()->actions(), QStringList()
-                 << QStringLiteral("file") << QStringLiteral("separator") << QStringLiteral("help"));
+    checkActions(mainWindow.menuBar()->actions(), menus);
 }
 
 void KXmlGui_UnitTest::testShortcuts()
@@ -1085,6 +1072,9 @@ void KXmlGui_UnitTest::testSpecificApplicationLanguageQLocale()
     KDEPrivate::setApplicationSpecificLanguage("ru_RU");
     KDEPrivate::initializeLanguages();
 
+#ifdef Q_OS_WIN
+    QEXPECT_FAIL("", "KDEPrivate::initializeLanguages assumes that setting $LANGUAGE will have an effect, this isn't the case on Windows. Needs to be fixed.", Abort);
+#endif
     QCOMPARE(QLocale::system().language(), QLocale::Russian);
 
     KDEPrivate::setApplicationSpecificLanguage("wa");
@@ -1097,3 +1087,14 @@ void KXmlGui_UnitTest::testSpecificApplicationLanguageQLocale()
 
     QCOMPARE(QLocale::system(), originalSystemLocale);
 }
+
+void KXmlGui_UnitTest::testSingleModifierQKeySequenceEndsWithPlus()
+{
+    // Check that native texts of the Meta, Alt, Control, Shift, Keypad modifiers end in "+"
+    // we depend on that in KKeySequenceWidgetPrivate::updateShortcutDisplay()
+    QVERIFY(QKeySequence(Qt::MetaModifier).toString(QKeySequence::NativeText).endsWith(QLatin1Char('+')));
+    QVERIFY(QKeySequence(Qt::AltModifier).toString(QKeySequence::NativeText).endsWith(QLatin1Char('+')));
+    QVERIFY(QKeySequence(Qt::ControlModifier).toString(QKeySequence::NativeText).endsWith(QLatin1Char('+')));
+    QVERIFY(QKeySequence(Qt::ShiftModifier).toString(QKeySequence::NativeText).endsWith(QLatin1Char('+')));
+    QVERIFY(QKeySequence(Qt::KeypadModifier).toString(QKeySequence::NativeText).endsWith(QLatin1Char('+')));
+}
