@@ -1,27 +1,16 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 1999 Reginald Stadlbauer <reggie@kde.org>
-              (C) 1999 Simon Hausmann <hausmann@kde.org>
-              (C) 2000 Nicolas Hadacek <haadcek@kde.org>
-              (C) 2000 Kurt Granroth <granroth@kde.org>
-              (C) 2000 Michael Koch <koch@kde.org>
-              (C) 2001 Holger Freyther <freyther@kde.org>
-              (C) 2002 Ellis Whitehead <ellis@kde.org>
-              (C) 2002 Joseph Wenninger <jowenn@kde.org>
-              (C) 2005-2007 Hamish Rodda <rodda@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999 Reginald Stadlbauer <reggie@kde.org>
+    SPDX-FileCopyrightText: 1999 Simon Hausmann <hausmann@kde.org>
+    SPDX-FileCopyrightText: 2000 Nicolas Hadacek <haadcek@kde.org>
+    SPDX-FileCopyrightText: 2000 Kurt Granroth <granroth@kde.org>
+    SPDX-FileCopyrightText: 2000 Michael Koch <koch@kde.org>
+    SPDX-FileCopyrightText: 2001 Holger Freyther <freyther@kde.org>
+    SPDX-FileCopyrightText: 2002 Ellis Whitehead <ellis@kde.org>
+    SPDX-FileCopyrightText: 2002 Joseph Wenninger <jowenn@kde.org>
+    SPDX-FileCopyrightText: 2005-2007 Hamish Rodda <rodda@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "config-xmlgui.h"
@@ -180,7 +169,7 @@ void KActionCollection::setComponentName(const QString &cName)
         // As of now this only matters for global shortcuts. We could
         // thus relax the requirement and only refuse to change the component data
         // if we have actions with global shortcuts in this collection.
-        qCWarning(DEBUG_KXMLGUI) << "this does not work on a KActionCollection containing actions!";
+        qCWarning(DEBUG_KXMLGUI) << "KActionCollection::setComponentName does not work on a KActionCollection containing actions!" << cName;
     }
 
     if (!cName.isEmpty()) {
@@ -224,21 +213,23 @@ QList<QAction *> KActionCollection::actions() const
 const QList< QAction * > KActionCollection::actionsWithoutGroup() const
 {
     QList<QAction *> ret;
-    Q_FOREACH (QAction *action, d->actions)
+    for (QAction *action : qAsConst(d->actions)) {
         if (!action->actionGroup()) {
             ret.append(action);
         }
+    }
     return ret;
 }
 
 const QList< QActionGroup * > KActionCollection::actionGroups() const
 {
     QSet<QActionGroup *> set;
-    Q_FOREACH (QAction *action, d->actions)
+    for (QAction *action : qAsConst(d->actions)) {
         if (action->actionGroup()) {
             set.insert(action->actionGroup());
         }
-    return set.toList();
+    }
+    return set.values();
 }
 
 QAction *KActionCollection::addAction(const QString &name, QAction *action)
@@ -268,7 +259,7 @@ QAction *KActionCollection::addAction(const QString &name, QAction *action)
                 // In debug mode assert
                 Q_ASSERT(!KGlobalAccel::self()->hasShortcut(action));
                 // In release mode keep the old name
-                qCritical() << "Changing action name from " << objectName << " to " << indexName << "\nignored because of active global shortcut.";
+                qCCritical(DEBUG_KXMLGUI) << "Changing action name from " << objectName << " to " << indexName << "\nignored because of active global shortcut.";
                 indexName = objectName;
             }
 #endif
@@ -281,7 +272,7 @@ QAction *KActionCollection::addAction(const QString &name, QAction *action)
     // No name provided and the action had no name. Make one up. This will not
     // work when trying to save shortcuts. Both local and global shortcuts.
     if (indexName.isEmpty()) {
-        indexName = indexName.sprintf("unnamed-%p", (void *)action);
+        indexName = QString::asprintf("unnamed-%p", (void *)action);
         action->setObjectName(indexName);
     }
 
@@ -321,7 +312,7 @@ QAction *KActionCollection::addAction(const QString &name, QAction *action)
     d->actionByName.insert(indexName, action);
     d->actions.append(action);
 
-    Q_FOREACH (QWidget *widget, d->associatedWidgets) {
+    for (QWidget *widget : qAsConst(d->associatedWidgets)) {
         widget->addAction(action);
     }
 
@@ -330,20 +321,23 @@ QAction *KActionCollection::addAction(const QString &name, QAction *action)
     d->setComponentForAction(action);
 
     if (d->connectHovered) {
-        connect(action, SIGNAL(hovered()), SLOT(slotActionHovered()));
+        connect(action, &QAction::hovered,
+                this, &KActionCollection::slotActionHovered);
     }
 
     if (d->connectTriggered) {
-        connect(action, SIGNAL(triggered(bool)), SLOT(slotActionTriggered()));
+        connect(action, &QAction::triggered,
+                this, &KActionCollection::slotActionTriggered);
     }
 
     emit inserted(action);
+    emit changed();
     return action;
 }
 
 void KActionCollection::addActions(const QList<QAction *> &actions)
 {
-    Q_FOREACH (QAction *action, actions) {
+    for (QAction *action : actions) {
         addAction(action->objectName(), action);
     }
 }
@@ -360,13 +354,16 @@ QAction *KActionCollection::takeAction(QAction *action)
     }
 
     // Remove the action from all widgets
-    Q_FOREACH (QWidget *widget, d->associatedWidgets) {
+    for (QWidget *widget : qAsConst(d->associatedWidgets)) {
         widget->removeAction(action);
     }
 
     action->disconnect(this);
 
+#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
     emit removed(action);   //deprecated
+#endif
+    emit changed();
     return action;
 }
 
@@ -526,8 +523,6 @@ void KActionCollection::exportGlobalShortcuts(KConfigGroup *config, bool writeAl
         return;
     }
 
-    QList<QAction *> writeActions = actions();
-
     for (QMap<QString, QAction *>::ConstIterator it = d->actionByName.constBegin();
             it != d->actionByName.constEnd(); ++it) {
 
@@ -540,7 +535,7 @@ void KActionCollection::exportGlobalShortcuts(KConfigGroup *config, bool writeAl
         // If the action name starts with unnamed- spit out a warning. That name
         // will change at will and will break loading writing
         if (actionName.startsWith(QLatin1String("unnamed-"))) {
-            qCritical() << "Skipped exporting Shortcut for action without name " << action->text() << "!";
+            qCCritical(DEBUG_KXMLGUI) << "Skipped exporting Shortcut for action without name " << action->text() << "!";
             continue;
         }
 
@@ -612,7 +607,7 @@ bool KActionCollectionPrivate::writeKXMLGUIConfigFile()
         // If the action name starts with unnamed- spit out a warning and ignore
         // it. That name will change at will and will break loading writing
         if (actionName.startsWith(QLatin1String("unnamed-"))) {
-            qCritical() << "Skipped writing shortcut for action " << actionName << "(" << action->text() << ")!";
+            qCCritical(DEBUG_KXMLGUI) << "Skipped writing shortcut for action " << actionName << "(" << action->text() << ")!";
             continue;
         }
 
@@ -680,7 +675,7 @@ void KActionCollection::writeSettings(KConfigGroup *config, bool writeAll, QActi
         // If the action name starts with unnamed- spit out a warning and ignore
         // it. That name will change at will and will break loading writing
         if (actionName.startsWith(QLatin1String("unnamed-"))) {
-            qCritical() << "Skipped saving Shortcut for action without name " << action->text() << "!";
+            qCCritical(DEBUG_KXMLGUI) << "Skipped saving Shortcut for action without name " << action->text() << "!";
             continue;
         }
 
@@ -727,16 +722,20 @@ void KActionCollection::slotActionTriggered()
     }
 }
 
+#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
 void KActionCollection::slotActionHighlighted()
 {
     slotActionHovered();
 }
+#endif
 
 void KActionCollection::slotActionHovered()
 {
     QAction *action = qobject_cast<QAction *>(sender());
     if (action) {
+#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
         emit actionHighlighted(action);
+#endif
         emit actionHovered(action);
     }
 }
@@ -752,7 +751,10 @@ void KActionCollectionPrivate::_k_actionDestroyed(QObject *obj)
     }
 
     //HACK the object we emit is partly destroyed
+#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
     emit q->removed(action); //deprecated. remove in KDE5
+#endif
+    emit q->changed();
 }
 
 void KActionCollection::connectNotify(const QMetaMethod &signal)
@@ -761,20 +763,25 @@ void KActionCollection::connectNotify(const QMetaMethod &signal)
         return;
     }
 
-    if (signal.methodSignature() == "actionHighlighted(QAction*)" ||
+    if (
+#if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
+        signal.methodSignature() == "actionHighlighted(QAction*)" ||
+#endif
             signal.methodSignature() == "actionHovered(QAction*)") {
         if (!d->connectHovered) {
             d->connectHovered = true;
-            Q_FOREACH (QAction *action, actions()) {
-                connect(action, SIGNAL(hovered()), SLOT(slotActionHovered()));
+            for (QAction *action : qAsConst(d->actions)) {
+                connect(action, &QAction::hovered,
+                        this, &KActionCollection::slotActionHovered);
             }
         }
 
     } else if (signal.methodSignature() == "actionTriggered(QAction*)") {
         if (!d->connectTriggered) {
             d->connectTriggered = true;
-            Q_FOREACH (QAction *action, actions()) {
-                connect(action, SIGNAL(triggered(bool)), SLOT(slotActionTriggered()));
+            for (QAction *action: qAsConst(d->actions)) {
+                connect(action, &QAction::triggered,
+                        this, &KActionCollection::slotActionTriggered);
             }
         }
     }
@@ -789,7 +796,7 @@ const QList< KActionCollection * > &KActionCollection::allCollections()
 
 void KActionCollection::associateWidget(QWidget *widget) const
 {
-    Q_FOREACH (QAction *action, actions()) {
+    for (QAction *action : qAsConst(d->actions)) {
         if (!widget->actions().contains(action)) {
             widget->addAction(action);
         }
@@ -808,7 +815,7 @@ void KActionCollection::addAssociatedWidget(QWidget *widget)
 
 void KActionCollection::removeAssociatedWidget(QWidget *widget)
 {
-    Q_FOREACH (QAction *action, actions()) {
+    for (QAction *action : qAsConst(d->actions)) {
         widget->removeAction(action);
     }
 
@@ -842,8 +849,8 @@ QAction *KActionCollectionPrivate::unlistAction(QAction *action)
     actions.removeAt(index);
 
     // Remove the action from the categories. Should be only one
-    QList<KActionCategory *> categories = q->findChildren<KActionCategory *>();
-    Q_FOREACH (KActionCategory *category, categories) {
+    const QList<KActionCategory *> categories = q->findChildren<KActionCategory *>();
+    for (KActionCategory *category : categories) {
         category->unlistAction(action);
     }
 
@@ -857,10 +864,11 @@ QList< QWidget * > KActionCollection::associatedWidgets() const
 
 void KActionCollection::clearAssociatedWidgets()
 {
-    Q_FOREACH (QWidget *widget, d->associatedWidgets)
-        Q_FOREACH (QAction *action, actions()) {
+    for (QWidget *widget : qAsConst(d->associatedWidgets)) {
+        for (QAction *action : qAsConst(d->actions)) {
             widget->removeAction(action);
         }
+    }
 
     d->associatedWidgets.clear();
 }
