@@ -1,20 +1,8 @@
-/* This file is part of the KDE project
-   Copyright (C) 1999 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 1999 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kbugreport.h"
@@ -34,7 +22,6 @@
 #include <QLineEdit>
 #include <QStandardPaths>
 #include <QTextEdit>
-#include <QDebug>
 #include <QHBoxLayout>
 #include <QGridLayout>
 
@@ -46,6 +33,7 @@
 #include <kmessagebox.h>
 #include <ktitlewidget.h>
 
+#include "debug.h"
 #include "../kxmlgui_version.h"
 #include "systeminformation_p.h"
 #include "config-xmlgui.h"
@@ -130,7 +118,8 @@ KBugReport::KBugReport(const KAboutData &aboutData, QWidget *_parent)
 
     KTitleWidget *title = new KTitleWidget(this);
     title->setText(i18n("Submit Bug Report"));
-    title->setPixmap(QIcon::fromTheme(QStringLiteral("tools-report-bug")).pixmap(32));
+    title->setIconSize(QSize(32, 32));
+    title->setIcon(QIcon::fromTheme(QStringLiteral("tools-report-bug")));
     lay->addWidget(title);
 
     QGridLayout *glay = new QGridLayout();
@@ -349,7 +338,7 @@ void KBugReportPrivate::_k_slotConfigureEmail()
     }
     m_process = new QProcess;
     QObject::connect(m_process, SIGNAL(finished(int,QProcess::ExitStatus)), q, SLOT(_k_slotSetFrom()));
-    m_process->start(QStringLiteral("kcmshell5"), QStringList() << QStringLiteral("user_manager"));
+    m_process->start(QStringLiteral("kcmshell5"), QStringList() << QStringLiteral("kcm_users"));
     if (!m_process->waitForStarted()) {
         //qCDebug(DEBUG_KXMLGUI) << "Couldn't start kcmshell5..";
         delete m_process;
@@ -512,7 +501,7 @@ bool KBugReport::sendBugReport()
     proc.start(command, args);
     //qCDebug(DEBUG_KXMLGUI) << command << args;
     if (!proc.waitForStarted()) {
-        qCritical() << "Unable to open a pipe to " << command;
+        qCCritical(DEBUG_KXMLGUI) << "Unable to open a pipe to " << command;
         return false;
     }
     proc.write(text().toUtf8());
