@@ -1,20 +1,8 @@
-/* This file is part of the KDE project
-   Copyright (C) 2006  Olivier Goffart  <ogoffart@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2006 Olivier Goffart <ogoffart@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kmenumenuhandler_p.h"
@@ -98,7 +86,8 @@ void KMenuMenuHandler::buildToolbarAction()
         return;
     }
     QStringList toolbarlist;
-    foreach (KToolBar *b, window->toolBars()) {
+    const auto toolbars = window->toolBars();
+    for (KToolBar *b : toolbars) {
         toolbarlist << (b->windowTitle().isEmpty() ? b->objectName() : b->windowTitle());
     }
     m_toolbarAction->setItems(toolbarlist);
@@ -106,7 +95,8 @@ void KMenuMenuHandler::buildToolbarAction()
 
 static KActionCollection *findParentCollection(KXMLGUIFactory *factory, QAction *action)
 {
-    foreach (KXMLGUIClient *client, factory->clients()) {
+    const auto clients = factory->clients();
+    for (KXMLGUIClient *client : clients) {
         KActionCollection *collection = client->actionCollection();
         // if the call to actions() is too slow, add KActionCollection::contains(QAction*).
         if (collection->actions().contains(action)) {
@@ -140,7 +130,8 @@ void KMenuMenuHandler::slotSetShortcut()
         QList<KActionCollection *> checkCollections;
         KXMLGUIFactory *factory = dynamic_cast<KXMLGUIClient *>(m_builder)->factory();
         parentCollection = findParentCollection(factory, m_popupAction);
-        foreach (KXMLGUIClient *client, factory->clients()) {
+        const auto clients = factory->clients();
+        for (KXMLGUIClient *client : clients) {
             checkCollections += client->actionCollection();
         }
         swidget.setCheckActionCollections(checkCollections);
@@ -229,7 +220,7 @@ void KMenuMenuHandler::showContextMenu(QMenu *menu, const QPoint &pos)
     m_popupAction = action;
 
     m_contextMenu = new QMenu;
-    m_contextMenu->addAction(i18n("Configure Shortcut..."), this, &KMenuMenuHandler::slotSetShortcut);
+    m_contextMenu->addAction(i18nc("@action:inmenu", "Configure Shortcut..."), this, &KMenuMenuHandler::slotSetShortcut);
 
     KMainWindow *window = qobject_cast<KMainWindow *>(m_builder->widget());
     if (window) {
