@@ -1,27 +1,15 @@
-/* This file is part of the KDE libraries
-    Copyright
-    (C) 2000 Reginald Stadlbauer (reggie@kde.org)
-    (C) 1997, 1998 Stephan Kulow (coolo@kde.org)
-    (C) 1997, 1998 Mark Donohoe (donohoe@kde.org)
-    (C) 1997, 1998 Sven Radej (radej@kde.org)
-    (C) 1997, 1998 Matthias Ettrich (ettrich@kde.org)
-    (C) 1999 Chris Schlaeger (cs@kde.org)
-    (C) 1999 Kurt Granroth (granroth@kde.org)
-    (C) 2005-2006 Hamish Rodda (rodda@kde.org)
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Reginald Stadlbauer <reggie@kde.org>
+    SPDX-FileCopyrightText: 1997, 1998 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 1997, 1998 Mark Donohoe <donohoe@kde.org>
+    SPDX-FileCopyrightText: 1997, 1998 Sven Radej <radej@kde.org>
+    SPDX-FileCopyrightText: 1997, 1998 Matthias Ettrich <ettrich@kde.org>
+    SPDX-FileCopyrightText: 1999 Chris Schlaeger <cs@kde.org>
+    SPDX-FileCopyrightText: 1999 Kurt Granroth <granroth@kde.org>
+    SPDX-FileCopyrightText: 2005-2006 Hamish Rodda <rodda@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "ktoolbar.h"
@@ -328,10 +316,10 @@ QMenu *KToolBar::Private::contextMenu(const QPoint &globalPos)
 
         contextMode = new QMenu(i18n("Text Position"), context);
 
-        contextIcons = contextMode->addAction(i18n("Icons Only"), q, SLOT(slotContextIcons()));
-        contextText = contextMode->addAction(i18n("Text Only"), q, SLOT(slotContextText()));
-        contextTextRight = contextMode->addAction(i18n("Text Alongside Icons"), q, SLOT(slotContextTextRight()));
-        contextTextUnder = contextMode->addAction(i18n("Text Under Icons"), q, SLOT(slotContextTextUnder()));
+        contextIcons = contextMode->addAction(i18nc("@item:inmenu", "Icons Only"), q, SLOT(slotContextIcons()));
+        contextText = contextMode->addAction(i18nc("@item:inmenu", "Text Only"), q, SLOT(slotContextText()));
+        contextTextRight = contextMode->addAction(i18nc("@item:inmenu", "Text Alongside Icons"), q, SLOT(slotContextTextRight()));
+        contextTextUnder = contextMode->addAction(i18nc("@item:inmenu", "Text Under Icons"), q, SLOT(slotContextTextUnder()));
 
         QActionGroup *textGroup = new QActionGroup(contextMode);
         const auto modeActions = contextMode->actions();
@@ -1188,7 +1176,7 @@ void KToolBar::dragLeaveEvent(QDragLeaveEvent *event)
 void KToolBar::dropEvent(QDropEvent *event)
 {
     if (toolBarsEditable()) {
-        Q_FOREACH (QAction *action, d->actionsBeingDragged) {
+        for (QAction *action : qAsConst(d->actionsBeingDragged)) {
             if (actions().contains(action)) {
                 removeAction(action);
             }
