@@ -1,20 +1,9 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2000 Simon Hausmann <hausmann@kde.org>
-   Copyright (C) 2000 Kurt Granroth <granroth@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Simon Hausmann <hausmann@kde.org>
+    SPDX-FileCopyrightText: 2000 Kurt Granroth <granroth@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kxmlguiclient.h"
@@ -332,10 +321,10 @@ void KXMLGUIClient::setXML(const QString &document, bool merge)
         setDOMDocument(doc, merge);
     } else {
 #ifdef NDEBUG
-        qCritical() << "Error parsing XML document:" << errorMsg << "at line" << errorLine << "column" << errorColumn;
+        qCCritical(DEBUG_KXMLGUI) << "Error parsing XML document:" << errorMsg << "at line" << errorLine << "column" << errorColumn;
         setDOMDocument(QDomDocument(), merge); // otherwise empty menus from ui_standards.rc stay around
 #else
-        qCritical() << "Error parsing XML document:" << errorMsg << "at line" << errorLine << "column" << errorColumn;
+        qCCritical(DEBUG_KXMLGUI) << "Error parsing XML document:" << errorMsg << "at line" << errorLine << "column" << errorColumn;
         abort();
 #endif
     }
@@ -806,3 +795,77 @@ void KXMLGUIClient::virtual_hook(int, void *)
 {
     /*BASE::virtual_hook( id, data );*/
 }
+
+QString KXMLGUIClient::findVersionNumber(const QString &xml)
+{
+    enum { ST_START, ST_AFTER_OPEN, ST_AFTER_GUI,
+           ST_EXPECT_VERSION, ST_VERSION_NUM
+         } state = ST_START;
+    const int length = xml.length();
+    for (int pos = 0; pos < length; pos++) {
+        switch (state) {
+        case ST_START:
+            if (xml[pos] == QLatin1Char('<')) {
+                state = ST_AFTER_OPEN;
+            }
+            break;
+        case ST_AFTER_OPEN: {
+            //Jump to gui..
+            const int guipos = xml.indexOf(QLatin1String("gui"), pos, Qt::CaseInsensitive);
+            if (guipos == -1) {
+                return QString();    //Reject
+            }
+
+            pos = guipos + 2; //Position at i, so we're moved ahead to the next character by the ++;
+            state = ST_AFTER_GUI;
+            break;
+        }
+        case ST_AFTER_GUI:
+            state = ST_EXPECT_VERSION;
+            break;
+        case ST_EXPECT_VERSION: {
+            const int verpos = xml.indexOf(QLatin1String("version"), pos, Qt::CaseInsensitive);
+            if (verpos == -1) {
+                return QString();    //Reject
+            }
+            pos = verpos + 7; // strlen("version") is 7
+            while (xml.at(pos).isSpace()) {
+                ++pos;
+            }
+            if (xml.at(pos++) != QLatin1Char('=')) {
+                return QString();    //Reject
+            }
+            while (xml.at(pos).isSpace()) {
+                ++pos;
+            }
+
+            state = ST_VERSION_NUM;
+            break;
+        }
+        case ST_VERSION_NUM: {
+            int endpos;
+            for (endpos = pos; endpos < length; endpos++) {
+                const ushort ch = xml[endpos].unicode();
+                if (ch >= QLatin1Char('0') && ch <= QLatin1Char('9')) {
+                    continue;    //Number..
+                }
+                if (ch == QLatin1Char('"')) { //End of parameter
+                    break;
+                } else { //This shouldn't be here..
+                    endpos = length;
+                }
+            }
+
+            if (endpos != pos && endpos < length) {
+                const QString matchCandidate = xml.mid(pos, endpos - pos); //Don't include " ".
+                return matchCandidate;
+            }
+
+            state = ST_EXPECT_VERSION; //Try to match a well-formed version..
+            break;
+        } //case..
+        } //switch
+    } //for
+
+    return QString();
+}
