@@ -1,28 +1,14 @@
 /*
     This file is part of the KDE libraries
-     Copyright
-     (C) 2000 Reginald Stadlbauer (reggie@kde.org)
-     (C) 1997 Stephan Kulow (coolo@kde.org)
-     (C) 1997-2000 Sven Radej (radej@kde.org)
-     (C) 1997-2000 Matthias Ettrich (ettrich@kde.org)
-     (C) 1999 Chris Schlaeger (cs@kde.org)
-     (C) 2002 Joseph Wenninger (jowenn@kde.org)
-     (C) 2005-2006 Hamish Rodda (rodda@kde.org)
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-FileCopyrightText: 2000 Reginald Stadlbauer <reggie@kde.org>
+    SPDX-FileCopyrightText: 1997 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 1997-2000 Sven Radej <radej@kde.org>
+    SPDX-FileCopyrightText: 1997-2000 Matthias Ettrich <ettrich@kde.org>
+    SPDX-FileCopyrightText: 1999 Chris Schlaeger <cs@kde.org>
+    SPDX-FileCopyrightText: 2002 Joseph Wenninger <jowenn@kde.org>
+    SPDX-FileCopyrightText: 2005-2006 Hamish Rodda <rodda@kde.org>
 
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KXMLGUIWINDOW_H
@@ -31,7 +17,6 @@
 #include "kxmlguiclient.h"
 #include "kxmlguibuilder.h"
 #include "kmainwindow.h"
-#include <QtCore/QMetaClassInfo>
 
 class KMenu;
 class KXMLGUIFactory;
@@ -40,16 +25,16 @@ class KConfigGroup;
 class KToolBar;
 class KXmlGuiWindowPrivate;
 
-#define KDE_DEFAULT_WINDOWFLAGS 0
-
 /**
- * @short %KDE top level main window with predefined action layout
+ * @class KXmlGuiWindow kxmlguiwindow.h KXmlGuiWindow
+ *
+ * @short Top level main window with predefined action layout
  *
  * Instead of creating a KMainWindow manually and assigning menus, menu entries,
  * toolbar buttons and actions to it by hand, this class can be used to load an
  * rc file to manage the main window's actions.
  *
- * See http://techbase.kde.org/Development/Tutorials/Using_KActions#XMLGUI
+ * See https://techbase.kde.org/Development/Tutorials/Using_KActions#XMLGUI
  * for essential information on the XML file format and usage of this class.
  *
  * @see KMainWindow
@@ -71,27 +56,27 @@ public:
      * Construct a main window.
      *
      * @param parent The widget parent. This is usually 0 but it may also be the window
-     * group leader. In that case, the KMainWindow becomes sort of a
+     * group leader. In that case, the KXmlGuiWindow becomes sort of a
      * secondary window.
      *
-     * @param f Specify the widget flags. The default is
-     * Qt::Window and Qt::WA_DeleteOnClose.  Qt::Window indicates that a
-     * main window is a toplevel window, regardless of whether it has a
-     * parent or not. Qt::WA_DeleteOnClose indicates that a main window is
-     * automatically destroyed when its window is closed. Pass 0 if
-     * you do not want this behavior.
+     * @param f Specify the window flags. The default is none.
      *
-     * @see https://doc.qt.io/qt-5/qt.html#WindowType-enum
-     *
-     * KMainWindows must be created on the heap with 'new', like:
+     * Note that a KXmlGuiWindow per-default is created with the
+     * Qt::WA_DeleteOnClose attribute set, i.e. it is automatically destroyed
+     * when the window is closed. If you do not want this behavior, call
      * \code
-     * KMainWindow *kmw = new KMainWindow(...);
+     * window->setAttribute(Qt::WA_DeleteOnClose, false);
+     * \endcode
+     *
+     * KXmlGuiWindows must be created on the heap with 'new', like:
+     * \code
+     * KXmlGuiWindow *kmw = new KXmlGuiWindow(...);
      * kmw->setObjectName(...);
      * \endcode
      *
      * IMPORTANT: For session management and window management to work
      * properly, all main windows in the application should have a
-     * different name. If you don't do it, KMainWindow will create
+     * different name. If you don't do it, the base class KMainWindow will create
      * a unique name, but it's recommended to explicitly pass a window name that will
      * also describe the type of the window. If there can be several windows of the same
      * type, append '#' (hash) to the name, and KMainWindow will replace it with numbers to make
@@ -101,7 +86,7 @@ public:
      * for the composer windows "composer#".
      *
      */
-    explicit KXmlGuiWindow(QWidget *parent = nullptr, Qt::WindowFlags f = KDE_DEFAULT_WINDOWFLAGS);
+    explicit KXmlGuiWindow(QWidget *parent = nullptr, Qt::WindowFlags f = Qt::WindowFlags());
 
     /**
      * \brief Destructor.
@@ -109,10 +94,10 @@ public:
      * Will also destroy the toolbars, and menubar if
      * needed.
      */
-    virtual ~KXmlGuiWindow();
+    ~KXmlGuiWindow() override;
 
     /**
-     * Enables the build of a standard help menu when calling createGUI/setupGUI().
+     * Enables the build of a standard help menu when calling createGUI() or setupGUI().
      *
      * The default behavior is to build one, you must call this function
      * to disable it
@@ -120,7 +105,7 @@ public:
     void setHelpMenuEnabled(bool showHelpMenu = true);
 
     /**
-     * Return @p true when the help menu is enabled
+     * Return @c true when the help menu is enabled
      */
     bool isHelpMenuEnabled() const;
 
@@ -155,27 +140,28 @@ public:
      * &lt;Merge name="StandardToolBarMenuHandler" /&gt;
      * line to the settings menu section of your resource file ( usually appname.rc ).
      *
-     * Note that you should enable this feature before calling createGUI() ( or similar ) .
+     * @note You should enable this feature before calling createGUI() ( or similar ).
      */
     void setStandardToolBarMenuEnabled(bool enable);
     bool isStandardToolBarMenuEnabled() const;
 
     /**
      * Sets whether KMainWindow should provide a menu that allows showing/hiding
-     * of the statusbar ( using KToggleStatusBarAction ).
+     * of the statusbar ( using KStandardAction::showStatusbar()).
      *
      * The menu / menu item is implemented using xmlgui. It will be inserted
      * in your menu structure in the 'Settings' menu.
      *
-     * Note that you should enable this feature before calling createGUI()
-     * ( or similar ).
+     * @note You should enable this feature before calling createGUI() ( or similar ).
      *
      * If an application maintains the action on its own (i.e. never calls
      * this function) a connection needs to be made to let KMainWindow
      * know when that status (hidden/shown) of the statusbar has changed.
      * For example:
-     * connect(action, SIGNAL(activated()),
-     *         kmainwindow, SLOT(setSettingsDirty()));
+     * @code
+     * connect(action, &QAction::triggered,
+     *         kmainwindow, &KMainWindow::setSettingsDirty);
+     * @endcode
      * Otherwise the status (hidden/show) of the statusbar might not be saved
      * by KMainWindow.
      */
@@ -183,6 +169,7 @@ public:
 
     /**
      * @see setupGUI()
+     * @see StandardWindowOptions
      */
     enum StandardWindowOption {
         /**
@@ -199,31 +186,33 @@ public:
 
         /**
          * adds action to show/hide the statusbar if the
-         * statusbar exists.  @see createStandardStatusBarAction
+         * statusbar exists.
+         * @see createStandardStatusBarAction
          */
         StatusBar = 4,
 
         /**
          * auto-saves (and loads) the toolbar/menubar/statusbar settings and
-         * window size using the default name.  @see setAutoSaveSettings
+         * window size using the default name.
          *
          * Typically you want to let the default window size be determined by
          * the widgets size hints. Make sure that setupGUI() is called after
          * all the widgets are created ( including setCentralWidget ) so the
-         * default size's will be correct. @see setAutoSaveSettings for
-         * more information on this topic.
+         * default size's will be correct.
+         * @see setAutoSaveSettings
          */
         Save = 8,
 
         /**
          * calls createGUI() once ToolBar, Keys and Statusbar have been
-         * taken care of.  @see createGUI
+         * taken care of.
          *
-         * NOTE: when using KParts::MainWindow, remove this flag from the
+         * @note When using KParts::MainWindow, remove this flag from the
          * setupGUI call, since you'll be using createGUI(part) instead.
          * @code
          *     setupGUI(ToolBar | Keys | StatusBar | Save);
          * @endcode
+         * @see createGUI
          */
         Create = 16,
 
@@ -234,6 +223,9 @@ public:
         Default = ToolBar | Keys | StatusBar | Save | Create
     };
     Q_FLAG(StandardWindowOption)
+    /**
+     * Stores a combination of #StandardWindowOption values.
+     */
     Q_DECLARE_FLAGS(StandardWindowOptions, StandardWindowOption)
 
     /**
@@ -246,9 +238,9 @@ public:
      * @see StandardWindowOptions
      * @note Since this method will restore the state of the application (toolbar, dockwindows
      *       positions...), you need to have added all your actions to your toolbars etc before
-     *       calling to this method. (This note is only applicable if you are using the Default or
-     *       Save flag).
-     * @warning If you are calling createGUI yourself, remember to remove the Create flag from
+     *       calling to this method. (This note is only applicable if you are using the @c Default or
+     *       @c Save flag).
+     * @warning If you are calling createGUI yourself, remember to remove the @c Create flag from
      *          the @p options parameter.
      *
      */
@@ -259,16 +251,16 @@ public:
      * fashion.  The options are all enabled by default but can be turned
      * off if desired through the params or if the prereqs don't exists.
      *
-     * @p defaultSize The default size of the window
+     * @param defaultSize The default size of the window
      *
      * Typically this function replaces createGUI().
      *
      * @see StandardWindowOptions
      * @note Since this method will restore the state of the application (toolbar, dockwindows
      *       positions...), you need to have added all your actions to your toolbars etc before
-     *       calling to this method. (This note is only applicable if you are using the Default or
-     *       Save flag).
-     * @warning If you are calling createGUI yourself, remember to remove the Create flag from
+     *       calling to this method. (This note is only applicable if you are using the @c Default or
+     *       @c Save flag).
+     * @warning If you are calling createGUI yourself, remember to remove the @c Create flag from
      *          the @p options parameter. Also, call setupGUI always after you call createGUI.
      */
     void setupGUI(const QSize &defaultSize, StandardWindowOptions options = Default, const QString &xmlfile = QString());
@@ -284,7 +276,7 @@ public:
     void setupToolbarMenuActions();
 
     // KDE5 TODO: change it to "using KXMLGUIBuilder::finalizeGUI;"
-    void finalizeGUI(KXMLGUIClient *client) Q_DECL_OVERRIDE;
+    void finalizeGUI(KXMLGUIClient *client) override;
 
     /**
      * @internal
@@ -292,7 +284,7 @@ public:
     void finalizeGUI(bool force);
 
     // reimplemented for internal reasons
-    void applyMainWindowSettings(const KConfigGroup &config) Q_DECL_OVERRIDE;
+    void applyMainWindowSettings(const KConfigGroup &config) override;
 
 public Q_SLOTS:
     /**
@@ -330,7 +322,7 @@ protected:
      * if needed, once all constructor code for the main window has run.
      * Also reimplemented to catch when a QDockWidget is added or removed.
      */
-    bool event(QEvent *event) Q_DECL_OVERRIDE;
+    bool event(QEvent *event) override;
 
     /**
      * Checks if there are actions using the same shortcut. This is called
@@ -341,7 +333,7 @@ protected:
 
 protected Q_SLOTS:
     /**
-     * Rebuilds the GUI after KEditToolbar changed the toolbar layout.
+     * Rebuilds the GUI after KEditToolBar changed the toolbar layout.
      * @see configureToolbars()
      */
     virtual void saveNewToolbarConfig();
